@@ -38,10 +38,10 @@ package inc::MBX::Alien::FLTK::Base;
 
     sub compile {
         my ($self, $args) = @_;
-        local $^W = 0;
         my $cbuilder = $self->cbuilder;
-        local $cbuilder->{'quiet'} = 1;
-        local $cbuilder->{'config'}{'archlibexp'} = '---break---';
+
+        #local $^W = 0;
+        #local $cbuilder->{'quiet'} = 1;
         if (!$args->{'source'}) {
             (my $FH, $args->{'source'}) = tempfile(
                                      undef, SUFFIX => '.cpp'    #, UNLINK => 1
@@ -57,7 +57,7 @@ package inc::MBX::Alien::FLTK::Base;
             $self->add_to_cleanup($args->{'source'});
         }
         open(my ($OLDERR), ">&STDERR");
-        close *STDERR;
+        close *STDERR if $cbuilder->{'quiet'};
         my $obj = eval {
             $cbuilder->compile(
                   ($args->{'source'} !~ m[\.c$] ? ('C++' => 1) : ()),
@@ -172,16 +172,20 @@ package inc::MBX::Alien::FLTK::Base;
                 : ' -lfltk2_images '
             )
         );
-        $self->notes('include_dirs'  => {});
-        $self->notes('library_paths' => {});
+        $self->notes('include_dirs' => {});
+        $self->notes('lib_dirs'     => {});
         {
             print 'Locating library archiver... ';
-            my $ar = can_run('ar');
+            open(my ($OLDOUT), ">&STDOUT");
+            close *STDOUT;
+            my ($ar) = grep { run("$_ V") } can_run($Config{'ar'});
+            open(*STDOUT, '>&', $OLDOUT)
+                || exit !print "Couldn't restore STDOUT: $!\n";
             if (!$ar) {
                 print "Could not find the library archiver, aborting.\n";
                 exit 0;
             }
-            $ar .= ' cr' . (can_run('ranlib') ? 's' : '');
+            $ar .= ' cr' . (can_run($Config{'ranlib'}) ? 's' : '');
             $self->notes(AR => $ar);
             print "$ar\n";
         }
@@ -684,13 +688,17 @@ int main () {
         my ($self, $build) = @_;
         $self->quiet(1);
         $self->notes('libs' => []);
+        local $self->cbuilder->{'config'}{'archlibexp'} = '---break---';
         if (!chdir $self->base_dir()) {
             print 'Failed to cd to base directory';
             exit 0;
         }
         my $libs = $self->notes('libs_source');
-        for my $lib (sort { lc $a cmp lc $b } keys %$libs) {
-            next if $libs->{$lib}{'disabled'};
+        my @libs = sort { lc $a cmp lc $b }
+            grep { !$libs->{$_}{'disabled'} } keys %$libs;
+
+        #printf "The following libs will be built: %s\n", join ', ', @libs;
+        for my $lib (@libs) {
             print "Building $lib...\n";
             my $cwd = _abs(_cwd());
             if (!chdir $build->fltk_dir($libs->{$lib}{'directory'})) {
@@ -787,6 +795,7 @@ int main () {
         unshift @INC, (_path($self->base_dir, 'lib'));
         if (   (!$args{'no-git'})
             && (eval 'require ' . $self->module_name)
+            && ($self->module_name->can('_git_rev'))
             && ($self->module_name->_git_rev()))
         {   {
                 $args{'ext'} ||= [qw[tar.gz zip]];
@@ -867,21 +876,21 @@ int main () {
             require File::Fetch;
             $File::Fetch::TIMEOUT = $File::Fetch::TIMEOUT = 45;    # Be quick
             printf "Fetching SVN snapshot %d... ", $self->notes('svn');
-            my ($schemes, $exts, %mirrors)
+            my ($schemes, $exts, $mirrors)
                 = ($args{'scheme'}, $args{'ext'}, $self->_snapshot_mirrors());
             my ($attempt, $total)
                 = (
-                 0, scalar(@$schemes) * scalar(@$exts) * scalar(keys %mirrors)
+                0, scalar(@$schemes) * scalar(@$exts) * scalar(keys %$mirrors)
                 );
-            my $mirrors = [keys %mirrors];
+            my @mirrors = keys %$mirrors;
             {    # F-Y shuffle
-                my $i = @$mirrors;
+                my $i = @mirrors;
                 while (--$i) {
                     my $j = int rand($i + 1);
-                    @$mirrors[$i, $j] = @$mirrors[$j, $i];
+                    @mirrors[$i, $j] = @mirrors[$j, $i];
                 }
             }
-        SVN_MIRROR: for my $mirror (@$mirrors) {
+        SVN_MIRROR: for my $mirror (@mirrors) {
             EXT: for my $ext (@$exts) {
                 SCHEME: for my $scheme (@$schemes) {
                         printf "\n[%d/%d] Trying %s mirror based in %s... ",
@@ -890,7 +899,7 @@ int main () {
                             File::Fetch->new(
                               uri => sprintf
                                   '%s://%s/fltk/snapshots/fltk-%s-r%d.tar.%s',
-                              $scheme, $mirrors{$mirror},
+                              $scheme, $mirrors->{$mirror},
                               $self->notes('branch'),
                               $self->notes('svn'), $ext
                             );
@@ -915,7 +924,7 @@ int main () {
             if (!$archive) {    # bad news
                 my (@urls, $i);
                 for my $ext (@$exts) {
-                    for my $mirror (sort values %mirrors) {
+                    for my $mirror (sort values %$mirrors) {
                         for my $scheme (@$schemes) {
                             push @urls,
                                 sprintf
@@ -944,7 +953,6 @@ Please, use one of the following mirrors:
 Exiting...
 END
             }
-            $self->depends_on('verify_snapshot');
         }
         shift @INC;
         print "done.\n";
@@ -952,6 +960,7 @@ END
         $self->notes('snapshot_path' => $archive);
         $self->notes('snapshot_dir'  => $dir);       # Unused but good to know
              #$self->add_to_cleanup($dir);
+        $self->depends_on('verify_snapshot');
     }
 
     sub _snapshot_mirrors {
@@ -961,6 +970,7 @@ END
         $return
             = eval 'require '
             . $self->module_name
+            && $self->module_name->can('_snapshot_mirrors')
             ? $self->module_name->_snapshot_mirrors()
             : {
             'California, USA' => 'ftp.easysw.com/pub',
@@ -1030,7 +1040,7 @@ END
         local @INC = ('lib', @INC);
         unshift @INC, (_path($self->base_dir, 'lib'));
         eval 'require ' . $self->module_name;
-        my $key = $self->module_name->_git_rev() ? 'sanko-' : '';
+        my $key = $self->module_name->can('_git_rev') ? 'sanko-' : '';
         $self->depends_on('fetch_fltk');
         $args{'from'} ||= $self->notes('snapshot_path');
         $args{'to'}   ||= _rel(($self->notes('extract_dir')));
@@ -1038,7 +1048,7 @@ END
                && -d $args{'to'} . sprintf '/%sfltk-%s-%s',
                $key,
                $self->notes('branch'),
-               $key
+               $key && $self->module_name->can('_git_rev')
                ? $self->module_name->_git_rev()
                : 'r' . $self->notes('svn')
             )
@@ -1074,7 +1084,6 @@ END
 
     sub ACTION_configure {
         my ($self) = @_;
-        $self->depends_on('extract_fltk');
         if (!$self->notes('timestamp_configure')
 
             #   || !$self->notes('define')
@@ -1094,6 +1103,7 @@ END
         #    if -f $self->notes('config_yml')
         #        && -s $self->notes('config_yml');
         $self->depends_on('configure');
+        $self->depends_on('extract_fltk');
         if (!chdir $self->fltk_dir()) {
             print 'Failed to cd to '
                 . $self->fltk_dir()
@@ -1263,10 +1273,17 @@ END
             # first figure out which headers we can' t find...
             for my $header (@{$args->{'headers'}}) {
                 printf 'Trying to compile with %s... ', $header;
+                push @{$args->{'include_dirs'}}, $self->find_h($header);
                 if ($self->compile(
                             {code => "#include <$header>\n" . $args->{'code'},
-                             include_dirs => $args->{'include_dirs'},
-                             lib_dirs     => $args->{'lib_dirs'}
+                             include_dirs => [
+                                          $args->{'include_dirs'},
+                                          $self->find_h($header),
+                                          keys %{$self->notes('include_dirs')}
+                             ],
+                             lib_dirs => [$args->{'lib_dirs'},
+                                          keys %{$self->notes('lib_dirs')}
+                             ]
                             }
                     )
                     )
@@ -1285,8 +1302,14 @@ END
                                 join("\n",
                                 (map {"#include <$_>"} @{$args->{'headers'}}),
                                 $args->{'code'}),
-                            include_dirs       => $args->{'include_dirs'},
-                            lib_dirs           => $args->{'lib_dirs'},
+                            include_dirs => [
+                                          $args->{'include_dirs'},
+                                          keys %{$self->notes('include_dirs')}
+                            ],
+                            lib_dirs => [$args->{'lib_dirs'},
+                                         keys %{$self->notes('lib_dirs')},
+                                         $self->find_lib($lib)
+                            ],
                             extra_linker_flags => "-l$lib"
                            }
                     )
@@ -1311,8 +1334,13 @@ END
                 = File::Find::Rule->file()
                 ->name('lib' . $find . $Config{'_a'})->maxdepth(1)
                 ->in(split ' ', $dir);
-            printf "%s\n", @files ? 'found ' . (_dir($files[0])) : 'missing';
-            return _path((_dir($files[0])));
+            if (@files) {
+                printf "found in %s\n", _dir($files[0]);
+                $self->notes('lib_dirs')->{_path((_dir($files[0])))}++;
+                return _path((_dir($files[0])));
+            }
+            print "missing\n";
+            return ();
         }
 
         sub find_h {
@@ -1320,6 +1348,11 @@ END
             printf 'Looking for %s... ', $file;
             $dir = join ' ', ($dir || ''), $Config{'incpath'},
                 $Config{'usrinc'};
+            {    # work around bug in recent Strawberry perl
+                my @pth = split ' ', $Config{'libpth'};
+                s[lib$][include] for @pth;
+                $dir .= join ' ', @pth;
+            }
             $dir =~ s|\s+| |g;
             for my $test (split m[\s+]m, $dir) {
                 if (-e _path($test . '/' . $file)) {
