@@ -3,24 +3,11 @@ package Alien::FLTK2;
     use strict;
     use warnings;
     use File::Spec::Functions qw[catdir rel2abs canonpath];
-    our $BASE = 0; our $SVN = 6970; our $DEV = -25; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
-    sub _git_rev {'7f6c18b'}
-
-    sub _snapshot_mirrors {
-        return {
-            'Milky Way' => 'http://sankorobinson.com/fltk-2.0.x/snapshots/',
-
-            #'Github (temp)' => 'http://download.github.com/',
-            #'Github (gen)'  => 'http://waitdownload.github.com/'
-            'Github (perm)' => 'http://github.com/downloads/sanko/fltk-2.0.x/'
-
-                # waitdownload.github.com/sanko-fltk-2.0.x-fd41e31.tar.gz
-        };
-    }
+    our $BASE = 0; our $SVN = 7680; our $DEV = -2; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
 
     sub _md5 {
-        return {gz  => '8159cabebbd1b5b774b277827aa4e030',
-                bz2 => 'f78976d0ba1a5c845e14f4df96d580a0'
+        return {gz  => '6d3ea46a7392bccbcd96b6c6d569446f',
+                bz2 => '677cfe42553355bdc21d79722687c1b0'
         };
     }
     sub _unique_file { return 'src/Widget.cxx' }
@@ -139,7 +126,7 @@ package Alien::FLTK2;
 
 =head1 NAME
 
-Alien::FLTK2 - Build and use the experimental C<2.0.x> branch Fast Light Toolkit
+Alien::FLTK2 - Build and use the experimental 2.0.x branch Fast Light Toolkit
 
 =head1 Description
 
@@ -417,6 +404,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 L<Alien::FLTK2|Alien::FLTK2> is based in part on the work of the FLTK project.
 See http://www.fltk.org/.
 
-=for git $Id: FLTK2.pm 4c1b0cc 2010-09-07 04:05:07Z sanko@cpan.org $
+=for git $Id: FLTK2.pm 1a7dcc2 2010-09-09 03:59:14Z sanko@cpan.org $
 
 =cut
